sequencetools.split_sequence_extended_to_weights_without_overhang
=================================================================

.. autofunction:: abjad.tools.sequencetools.split_sequence_extended_to_weights_without_overhang.split_sequence_extended_to_weights_without_overhang
